@@ -1,5 +1,6 @@
-#include <catch2/catch.hpp>
 #include <panda/protocol/http.h>
+#include <catch2/catch_test_macros.hpp>
+#include <catch2/matchers/catch_matchers_string.hpp>
 
 using namespace panda;
 using namespace panda::protocol::http;
